==> jc-1.4.0.tar.gz: java/util/Timer__24TaskQueue.h <==
// final class java.util.Timer$TaskQueue

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32b6bf55256f57fc java_util_Timer__24TaskQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Timer__24TaskQueue_H_
#define _JC_java_util_Timer__24TaskQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_TimerTask$object;

// Typedefs
typedef struct _jc_java_util_Timer__24TaskQueue$sub_refs	_jc_java_util_Timer__24TaskQueue$sub_refs;
typedef struct _jc_java_util_Timer__24TaskQueue$sub_nonrefs	_jc_java_util_Timer__24TaskQueue$sub_nonrefs;
typedef struct _jc_java_util_Timer__24TaskQueue$refs	_jc_java_util_Timer__24TaskQueue$refs;
typedef struct _jc_java_util_Timer__24TaskQueue$nonrefs	_jc_java_util_Timer__24TaskQueue$nonrefs;
typedef struct _jc_java_util_Timer__24TaskQueue$object	_jc_java_util_Timer__24TaskQueue$object;

typedef struct _jc_java_util_Timer__24TaskQueue$fields_struct	_jc_java_util_Timer__24TaskQueue$fields_struct;
typedef const struct _jc_java_util_Timer__24TaskQueue$vmethods	_jc_java_util_Timer__24TaskQueue$vmethods;
typedef const struct _jc_java_util_Timer__24TaskQueue$vtable	_jc_java_util_Timer__24TaskQueue$vtable;
typedef const struct _jc_java_util_Timer__24TaskQueue$vtype	_jc_java_util_Timer__24TaskQueue$vtype;

// Class fields structure
struct _jc_java_util_Timer__24TaskQueue$fields_struct {
	jint	DEFAULT__5fSIZE;
};
extern _jc_java_util_Timer__24TaskQueue$fields_struct _jc_java_util_Timer__24TaskQueue$class_fields;

// Constructors
extern void _jc_java_util_Timer__24TaskQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);

// Virtual methods
extern void _jc_java_util_Timer__24TaskQueue$method$add$b5977b67fa578234(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *);
extern void _jc_java_util_Timer__24TaskQueue$method$enqueue$0a191031db69267e(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *);
extern void _jc_java_util_Timer__24TaskQueue$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
extern struct _jc_java_util_TimerTask$object *_jc_java_util_Timer__24TaskQueue$method$serve$634f629513fe88f0(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
extern void _jc_java_util_Timer__24TaskQueue$method$setNullOnEmpty$f6d64bc7a6df62a1(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, jboolean);
extern void _jc_java_util_Timer__24TaskQueue$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
extern struct _jc_java_util_TimerTask$object *_jc_java_util_Timer__24TaskQueue$method$top$74c69e311746a9ec(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$add$b5977b67fa578234;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$enqueue$0a191031db69267e;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$serve$634f629513fe88f0;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$setNullOnEmpty$f6d64bc7a6df62a1;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$top$74c69e311746a9ec;

// Virtual methods structure
struct _jc_java_util_Timer__24TaskQueue$vmethods {
	void	(*add$b5977b67fa578234)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *);
	void	(*enqueue$0a191031db69267e)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
	struct _jc_java_util_TimerTask$object	*(*serve$634f629513fe88f0)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
	void	(*setNullOnEmpty$f6d64bc7a6df62a1)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, jboolean);
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
	struct _jc_java_util_TimerTask$object	*(*top$74c69e311746a9ec)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *);
};

// Vtable
struct _jc_java_util_Timer__24TaskQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Timer__24TaskQueue$vmethods	java_util_Timer__24TaskQueue;
};

// Vtype
struct _jc_java_util_Timer__24TaskQueue$vtype {
	_jc_type			type;
	_jc_java_util_Timer__24TaskQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Timer__24TaskQueue$sub_refs {
	_jc_object_array	*heap;
};

// Reference instance fields (object)
struct _jc_java_util_Timer__24TaskQueue$refs {
    _jc_java_util_Timer__24TaskQueue$sub_refs	java_util_Timer__24TaskQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Timer__24TaskQueue$sub_nonrefs {
	jboolean	nullOnEmpty;
	jint	elements;
};

// Non-reference instance fields (object)
struct _jc_java_util_Timer__24TaskQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Timer__24TaskQueue$sub_nonrefs	java_util_Timer__24TaskQueue;
};

// Object instance structure
struct _jc_java_util_Timer__24TaskQueue$object {
	_jc_java_util_Timer__24TaskQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Timer__24TaskQueue$vtype	*vtype;
	_jc_java_util_Timer__24TaskQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Timer__24TaskQueue$vtype _jc_java_util_Timer__24TaskQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Timer__24TaskQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Timer__24TaskQueue$class_object;

#endif	/* _JC_java_util_Timer__24TaskQueue_H_ */

==> jc-1.4.6.tar.gz: java/util/Timer__24TaskQueue.h <==
// final class java.util.Timer$TaskQueue

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32b6bf55256f57fc java_util_Timer__24TaskQueue

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Timer__24TaskQueue_H_
#define _JC_java_util_Timer__24TaskQueue_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_TimerTask$object;

// Typedefs
typedef struct _jc_java_util_Timer__24TaskQueue$sub_refs	_jc_java_util_Timer__24TaskQueue$sub_refs;
typedef struct _jc_java_util_Timer__24TaskQueue$sub_nonrefs	_jc_java_util_Timer__24TaskQueue$sub_nonrefs;
typedef struct _jc_java_util_Timer__24TaskQueue$refs	_jc_java_util_Timer__24TaskQueue$refs;
typedef struct _jc_java_util_Timer__24TaskQueue$nonrefs	_jc_java_util_Timer__24TaskQueue$nonrefs;
typedef struct _jc_java_util_Timer__24TaskQueue$object	_jc_java_util_Timer__24TaskQueue$object;

typedef struct _jc_java_util_Timer__24TaskQueue$fields_struct	_jc_java_util_Timer__24TaskQueue$fields_struct;
typedef const struct _jc_java_util_Timer__24TaskQueue$vmethods	_jc_java_util_Timer__24TaskQueue$vmethods;
typedef const struct _jc_java_util_Timer__24TaskQueue$vtable	_jc_java_util_Timer__24TaskQueue$vtable;
typedef const struct _jc_java_util_Timer__24TaskQueue$vtype	_jc_java_util_Timer__24TaskQueue$vtype;

// Class fields structure
struct _jc_java_util_Timer__24TaskQueue$fields_struct {
	jint	DEFAULT__5fSIZE;
};
extern _jc_java_util_Timer__24TaskQueue$fields_struct _jc_java_util_Timer__24TaskQueue$class_fields;

// Constructors
extern void _jc_java_util_Timer__24TaskQueue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_Timer__24TaskQueue$method$add$b5977b67fa578234(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Timer__24TaskQueue$method$enqueue$0a191031db69267e(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Timer__24TaskQueue$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_TimerTask$object *_jc_java_util_Timer__24TaskQueue$method$serve$634f629513fe88f0(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Timer__24TaskQueue$method$setNullOnEmpty$f6d64bc7a6df62a1(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_util_Timer__24TaskQueue$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_TimerTask$object *_jc_java_util_Timer__24TaskQueue$method$top$74c69e311746a9ec(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$add$b5977b67fa578234;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$enqueue$0a191031db69267e;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$serve$634f629513fe88f0;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$setNullOnEmpty$f6d64bc7a6df62a1;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_java_util_Timer__24TaskQueue$method_info$top$74c69e311746a9ec;

// Virtual methods structure
struct _jc_java_util_Timer__24TaskQueue$vmethods {
	void	(*add$b5977b67fa578234)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
	void	(*enqueue$0a191031db69267e)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, struct _jc_java_util_TimerTask$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_TimerTask$object	*(*serve$634f629513fe88f0)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
	void	(*setNullOnEmpty$f6d64bc7a6df62a1)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *, jboolean) _JC_JCNI_ATTR;
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_TimerTask$object	*(*top$74c69e311746a9ec)(_jc_env *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Timer__24TaskQueue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Timer__24TaskQueue$vmethods	java_util_Timer__24TaskQueue;
};

// Vtype
struct _jc_java_util_Timer__24TaskQueue$vtype {
	_jc_type			type;
	_jc_java_util_Timer__24TaskQueue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Timer__24TaskQueue$sub_refs {
	_jc_object_array	*heap;
};

// Reference instance fields (object)
struct _jc_java_util_Timer__24TaskQueue$refs {
    _jc_java_util_Timer__24TaskQueue$sub_refs	java_util_Timer__24TaskQueue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Timer__24TaskQueue$sub_nonrefs {
	jboolean	nullOnEmpty;
	jint	elements;
};

// Non-reference instance fields (object)
struct _jc_java_util_Timer__24TaskQueue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Timer__24TaskQueue$sub_nonrefs	java_util_Timer__24TaskQueue;
};

// Object instance structure
struct _jc_java_util_Timer__24TaskQueue$object {
	_jc_java_util_Timer__24TaskQueue$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Timer__24TaskQueue$vtype	*vtype;
	_jc_java_util_Timer__24TaskQueue$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Timer__24TaskQueue$vtype _jc_java_util_Timer__24TaskQueue$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Timer__24TaskQueue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Timer__24TaskQueue$class_object;

#endif	/* _JC_java_util_Timer__24TaskQueue_H_ */
